@@ -1,5 +1,3 @@
-import React from 'react';
-
 import EmptyListCTA from 'app/core/components/EmptyListCTA/EmptyListCTA';
 import { contextSrv } from 'app/core/core';
 
@@ -11,7 +9,15 @@ export const CacheCTA = (props: Props) => {
   const { enableDataSourceCache, dataSource, pageId } = props;
   const canWriteCache = contextSrv.hasPermissionInMetadata(AccessControlAction.DataSourcesCachingWrite, dataSource);
 
-  return (
+  return dataSource.jsonData?.disableGrafanaCache ? (
+    <EmptyListCTA
+      title="Caching cannot be enabled for this data source."
+      buttonTitle="Enable"
+      buttonIcon="database"
+      proTip="This data source's configuration does not permit caching to be enabled."
+      buttonDisabled={true}
+    />
+  ) : (
     <EmptyListCTA
       title="Caching is not enabled for this data source."
       buttonTitle="Enable"
